@@ -154,6 +154,7 @@
 #'   change the start day by supplying an integer between 0 and 6. Sunday = 0,
 #'   Monday = 1, \ldots For example to start the weekday plots on a Saturday,
 #'   choose \code{start.day = 6}.
+#' @param panel.gap The gap between panels in the hour-day plot.
 #' @param auto.text Either \code{TRUE} (default) or \code{FALSE}. If \code{TRUE}
 #'   titles and axis labels will automatically try and format pollutant names
 #'   and units properly e.g.  by subscripting the \sQuote{2} in NO2.
@@ -264,6 +265,7 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
                           type = "default", group = NULL, difference = FALSE,
                           statistic = "mean", conf.int = 0.95, B = 100, ci = TRUE, cols = "hue",
                           ref.y = NULL, key = NULL, key.columns = 1, start.day = 1,
+                          panel.gap = 0.2,
                           auto.text = TRUE, alpha = 0.4, month.last = FALSE, plot = TRUE,
                           ...) {
 
@@ -907,6 +909,7 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
     xlab = xlab[1],
     layout = layout,
     par.settings = simpleTheme(col = myColors),
+    between = list(x = panel.gap),
     scales = list(x = list(at = c(0, 6, 12, 18, 23))),
     key = key,
     strip = strip,
